## plot data for PCM1 analysis

## use 'PCM1_assemble_data_from_reps.R' first to assemble data from Cell Profiler output
pcm_rep1 <- read.csv(file.choose())
pcm_rep1$rep <- "one" ## choose EXAMPLE_PCM1_rep1.csv

pcm_rep2 <- read.csv(file.choose())
pcm_rep2$rep <- "two" ## choose EXAMPLE_PCM1_rep2.csv

##load cep135 data for cell number
cep135rep1 <- read.csv(file.choose()) ## choose EXAMPLEshrink_CEP135.csv from Cell Profiler output
cep135rep2 <- read.csv(file.choose())

cep135rep1$id <- with(cep135rep1, paste(ImageNumber, Parent_sat_area, sep="_"))
cep135rep1$factor <- with(cep135rep1, paste(Metadata_line, Metadata_treatment, sep="_"))
cep135rep2$id <- with(cep135rep2, paste(ImageNumber, Parent_sat_area, sep="_"))
cep135rep2$factor <- with(cep135rep2, paste(Metadata_line, Metadata_treatment, sep="_"))

## add number of cell data per factor
library(plyr)
cep135rep1 <- ddply(cep135rep1, .(factor), summarize, number = length(factor))
cep135rep2 <- ddply(cep135rep2, .(factor), summarize, number = length(factor))

### add cell number data to pcm1 data
pcm_rep1_final <- merge(pcm_rep1, cep135rep1, by = "factor")
pcm_rep2_final <- merge(pcm_rep2, cep135rep2, by = "factor")

pcm <- rbind(pcm_rep1_final, pcm_rep2_final)

## background subtraction based on mean total PCM1KO intensities
## the average satellite intensity for objects detected in PCM1KO samples was used remove objects that were spuriously identified
## the background was calculated by normalizing to the mean of DMSO treated cells for each sample
## mean PCM1KO value 1.361993. mean DMSO to use for normalization 1.77882
## for example, if the DMSO control for the experiment was 2, subtract 2/1.77882 * 1.361993 = 1.531344
pcm$Integrated_sub <- pcm$Intensity_IntegratedIntensity_PCM1_sub - calculated_value_here
pcm$Integrated_sub <- ifelse (pcm$Integrated_sub < 0, 0, pcm$Integrated_sub) ## negative numbers converted to zero

## data are normalized to DMSO sample in the experiment
temp.mean <- ddply(pcm[pcm$factor == "EXAMPLE_DMSO",], .(rep), summarize, mean_per_factor = mean(Integrated_sub))
pcm <- merge(pcm, temp.mean, by = "rep")
pcm$intensity_norm <- pcm$Integrated_sub/(pcm$number)
pcm$Intensity_IntegratedIntensity_phsp27_sub.scale <- round(pcm$intensity_norm * 1000)

M <- pcm
data.order <- c("sample1", "sample2", "sample3", "etc...")

library(ggplot2)
library(viridis)

## generate all plots
graphs <- list()
for (i in 1:length(data.order)){
  
  x <- M[M$factor == data.order[i],14]
  y <- M[M$factor == data.order[i],15]
  df <- data.frame(x,y)
  reptimes <- as.numeric(M[M$factor == data.order[i],21])
  weightfactor = 1 ## should be integer, higher weight factor weights area more heavily relative to density of points (always 1)
  ## taking into account the number of replicates
  reptimes = round(weightfactor * reptimes / 2)
  idx <- rep(1:nrow(df), reptimes)
  repdf <- df[idx,]
  graphs[[i]] <- local({
    i <- i
    tempplot <- ggplot(repdf,aes(x=x,y=y))+
      geom_hex(binwidth = c(2,2)) +
      scale_fill_viridis(limits=c(0,2000),breaks=seq(0,2000,by=250), option = "C", oob = scales::squish) +
      coord_cartesian(xlim = c(-100,100), ylim = c(-100,100)) +
      ggtitle (paste(data.order[i])) +
      theme_bw()
  })
}

library(cowplot)
pcm_plots_all <- plot_grid(plotlist = graphs, ncol =2, align = "v")

## combined INNER only

M.inner <- M[M$sat_type == "inner",]
graphs <- list()
for (i in 1:length(data.order)){
  
  x <- M.inner[M.inner$factor == data.order[i],14]
  y <- M.inner[M.inner$factor == data.order[i],15]
  df <- data.frame(x,y)
  reptimes <- as.numeric(M.inner[M.inner$factor == data.order[i],21])
  weightfactor = 1 ## should be integer, higher weight factor weights area more heavily relative to density of points (always 1)
  ## taking into account the number of replicates
  reptimes = round(weightfactor * reptimes / 2)
  idx <- rep(1:nrow(df), reptimes)
  repdf <- df[idx,]
  graphs[[i]] <- local({
    i <- i
    tempplot <- ggplot(repdf,aes(x=x,y=y))+
      geom_hex(binwidth=c(1,1)) +
      scale_fill_viridis(limits=c(0,1000),breaks=seq(0,1000,by=250), option = "C", oob = scales::squish) +
      coord_cartesian(xlim = c(-15,15), ylim = c(-15,15)) +
      ggtitle (data.order[i]) +
      theme_bw()
  })
}

library(cowplot)
pcm_combined_inner <- plot_grid(plotlist = graphs, ncol =2, align = "v")
rm(graphs)

##counting inner and outer intensities per rep
count_rep <- ddply(M, .(factor, rep, sat_type), summarize, sum_scale_intensity = sum(Intensity_IntegratedIntensity_phsp27_sub.scale))
library(reshape2)
count_rep.c <- dcast(count_rep, factor + rep ~ sat_type)
count_rep.c$percent <- count_rep.c$inner / (count_rep.c$inner + count_rep.c$outer)
write.csv(count_rep.c, "EXAMPLE_pcm_reps.csv", row.names = FALSE)

##counting inner and outer intensities
count_rep.all <- ddply(M, .(factor, sat_type), summarize, sum_scale_intensity = sum(Intensity_IntegratedIntensity_phsp27_sub.scale))
library(reshape2)
count_rep.all.c <- dcast(count_rep.all, factor ~ sat_type)
count_rep.all.c$percent <- count_rep.all.c$inner / (count_rep.all.c$inner + count_rep.all.c$outer)
write.csv(count_rep.all.c, "EXAMPLE_pcm_count_combined.csv", row.names = FALSE)
