## assemble data from Cell Profiler output
## use EXAMPLE_phsp27aggresome.csv file

data_agg_rep1 <- read.csv(file.choose())
data_agg_rep1$factor <- with(data_agg_rep1, paste(Metadata_line, Metadata_treatment, sep="_"))
data_agg_rep1$rep <- "one"

data_agg_rep2 <- read.csv(file.choose())
data_agg_rep2$factor <- with(data_agg_rep2, paste(Metadata_line, Metadata_treatment, sep="_"))
data_agg_rep2$rep <- "two"

data_agg <- rbind(data_agg_rep1, data_agg_rep2)

library(ggplot2)

##plot combined reps
plot_area_agg2 <- ggplot(data_agg[data_agg$AreaShape_Area < 1000,], aes (x = factor, y = AreaShape_Area)) +
  geom_boxplot(outlier.shape = NA, colour = "blue", lwd = 1, fill = NA) +
  geom_jitter(alpha = 0.5, pch =21, size =1, width = 0.25) +
  theme_bw() +
  scale_x_discrete(limits=c("sample1", "sample2", "sample3", "etc...")) +
  ggtitle("pHsp27 Area")


##statistics area

data_agg_stat_rep1 <- data_agg_rep1[data_agg_rep1$AreaShape_Area < 1000,]
data_agg_stat_rep2 <- data_agg_rep2[data_agg_rep2$AreaShape_Area < 1000,]
data_agg_stat <- data_agg[data_agg$AreaShape_Area < 1000,]

library(dunn.test)

rep1.dunn <- dunn.test(data_agg_stat_rep1$AreaShape_Area, data_agg_stat_rep1$factor, method = "bh", kw = TRUE, list = TRUE)
rep1.dunn.table <- cbind.data.frame(comparison = rep1.dunn$comparisons,Z.stat = rep1.dunn$Z, P.adj = rep1.dunn$P.adjusted)
write.csv(rep1.dunn.table, "EXAMPLE_rep1_area_stats.csv", row.names=FALSE, quote = FALSE)

rep2.dunn <- dunn.test(data_agg_stat_rep2$AreaShape_Area, data_agg_stat_rep2$factor, method = "bh", kw = TRUE, list = TRUE)
rep2.dunn.table <- cbind.data.frame(comparison = rep2.dunn$comparisons,Z.stat = rep2.dunn$Z, P.adj = rep2.dunn$P.adjusted)
write.csv(rep2.dunn.table, "EXAMPLE_rep2_area_stats.csv", row.names=FALSE, quote = FALSE)

all.dunn <- dunn.test(data_agg_stat$AreaShape_Area, data_agg_stat$factor, method = "bh", kw = TRUE, list = TRUE)
all.dunn.table <- cbind.data.frame(comparison = all.dunn$comparisons,Z.stat = all.dunn$Z, P.adj = all.dunn$P.adjusted)
write.csv(all.dunn.table, "EXAMPLE_combined_area_stats.csv", row.names=FALSE, quote = FALSE)

## run data_agg_stat before this!!!!
library(psych)
phsp27_summary <- describeBy(data_agg_stat[, c(11,31)], data_agg_stat$factor)
phsp27_summary_frame <- do.call("rbind", phsp27_summary)
write.csv(phsp27_summary_frame, "EXAMPLE_phsp27_summary.csv", quote = FALSE)
